@@ -3,6 +3,7 @@ package gen
 import (
 	"fmt"
 	"path/filepath"
+	"strings"
 	"time"
 
 	"cuelang.org/go/cue"
@@ -49,6 +50,10 @@ type Generator struct {
 	In  map[string]interface{}
 	Val cue.Value
 
+	// File globs to watch and trigger regen on change
+	WatchFull []string
+	WatchFast  []string
+
 	// The list fo files for hof to generate, in cue values
 	Out []*File
 
@@ -77,6 +82,9 @@ type Generator struct {
 	// Used for indexing into the vendor directory...
 	PackageName string
 
+	// Use Diff3 & Shadow
+	UseDiff3 bool
+
 	//
 	// Hof internal usage
 	//
@@ -90,6 +98,7 @@ type Generator struct {
 	PartialsMap templates.TemplateMap
 
 	// Files and the shadow dir for doing neat things
+	OrderedFiles    []*File
 	Files  map[string]*File
 	Shadow map[string]*File
 
@@ -113,24 +122,23 @@ func NewGenerator(label string, value cue.Value) *Generator {
 		Files:       make(map[string]*File),
 		Shadow:      make(map[string]*File),
 		Stats:       &GeneratorStats{},
+		UseDiff3:    true,
 	}
 }
 
-func (G *Generator) GenerateFiles() []error {
+func (G *Generator) GenerateFiles(outdir string) []error {
 	errs := []error{}
 
 	start := time.Now()
 
-	for _, F := range G.Files {
-
+	for _, F := range G.OrderedFiles {
 		if F.Filepath == "" {
 			F.IsSkipped = 1
 			continue
 		}
-		shadowFN := filepath.Join(G.Name, F.Filepath)
-		F.ShadowFile = G.Shadow[shadowFN]
+		F.ShadowFile = G.Shadow[F.Filepath]
 
-		err := F.Render(filepath.Join(SHADOW_DIR, shadowFN))
+		err := F.Render(outdir, G.UseDiff3)
 		if err != nil {
 			F.IsErr = 1
 			F.Errors = append(F.Errors, err)
@@ -269,10 +277,25 @@ func (G *Generator) initFileGens() []error {
 	var errs []error
 
 	for _, F := range G.Out {
+		// support text/template in output file path
+		if strings.Contains(F.Filepath, "{{") {
+			ft, err := templates.CreateFromString("filepath", F.Filepath, nil)
+			if err != nil {
+				errs = append(errs, err)
+			}
+			bs, err := ft.Render(F.In)
+			if err != nil {
+				errs = append(errs, err)
+			}
+			F.Filepath = string(bs)
+		}
+
+		F.Filepath = filepath.Clean(F.Filepath)
+		G.OrderedFiles = append(G.OrderedFiles, F)
 		G.Files[F.Filepath] = F
 	}
 
-	for _, F := range G.Files {
+	for _, F := range G.OrderedFiles {
 		err := G.ResolveFile(F)
 		if err != nil {
 			errs = append(errs, err)
@@ -327,8 +350,6 @@ func (G *Generator) registerPartials(T *templates.Template) error {
 		// maybe? because of how text/template contexts work
 		templates.AddGolangHelpers(t)
 		t.Parse(P.Source)
-
-		// T.T = t
 	}
 
 	return nil
