@@ -4,22 +4,20 @@ import (
 	"fmt"
 	"io/ioutil"
 	"os"
-	"path"
 	"path/filepath"
 	"strings"
 )
 
 const SHADOW_DIR = ".hof/shadow/"
 
-func LoadShadow(subdir string, verbose bool) (map[string]*File, error) {
-	if verbose {
-		fmt.Printf("Loading shadow @ %q\n", SHADOW_DIR)
-	}
-
+func LoadShadow(subdir string, verbosity int) (map[string]*File, error) {
 	shadowDir := filepath.Join(SHADOW_DIR, subdir)
-
 	shadow := map[string]*File{}
 
+	if verbosity > 1 {
+		fmt.Printf("Loading shadow @ %q\n", shadowDir)
+	}
+
 	_, err := os.Lstat(shadowDir)
 	if err != nil {
 		// make sure we check err for something actually bad
@@ -27,7 +25,7 @@ func LoadShadow(subdir string, verbose bool) (map[string]*File, error) {
 			return nil, err
 		}
 		// file not found, leave politely
-		if verbose {
+		if verbosity > 1 {
 			fmt.Println("  shadow not found")
 		}
 		return shadow, nil
@@ -39,12 +37,22 @@ func LoadShadow(subdir string, verbose bool) (map[string]*File, error) {
 			return nil
 		}
 
-		if verbose {
-			fmt.Println("  adding:", info.Name())
+		// read contents
+		bytes, err := ioutil.ReadFile(fpath)
+		if err != nil {
+			return err
 		}
 
-		fpath = strings.TrimPrefix(fpath, SHADOW_DIR)
-		shadow[fpath] = &File {
+		// simplify path
+		fpath = strings.TrimPrefix(fpath, shadowDir + "/")
+
+		// debug
+		if verbosity > 1 {
+			fmt.Println("  adding:", fpath)
+		}
+
+		shadow[fpath] = &File{
+			FinalContent: bytes,
 			Filepath: fpath,
 		}
 
@@ -52,28 +60,9 @@ func LoadShadow(subdir string, verbose bool) (map[string]*File, error) {
 	})
 
 	if err != nil {
-		err = fmt.Errorf("error walking the shadow dir %q: %w\n", SHADOW_DIR, err)
+		err = fmt.Errorf("error walking the shadow dir %q: %w\n", shadowDir, err)
 		return nil, err
 	}
 
 	return shadow, nil
 }
-
-func (F *File) ReadShadow() error {
-	if F.ShadowFile == nil {
-		return nil
-	}
-
-	// Should have already been confirmed to exist at this point
-	shadowFN := path.Join(SHADOW_DIR, F.ShadowFile.Filepath)
-	// fmt.Println("ReadShadow", shadowFN)
-	bytes, err := ioutil.ReadFile(shadowFN)
-	if err != nil {
-		return err
-	}
-
-	F.ShadowFile.FinalContent = bytes
-
-	return nil
-}
-
